"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const ownership_1 = require("@snyk/github-codeowners/dist/lib/ownership");
const path_1 = require("../util/path");
const constants_1 = require("./constants");
const logIssueLine = (owner, filePath, symbols) => {
    console.log(`${owner} ${(0, path_1.relative)(filePath)}${symbols ? `: ${symbols.join(', ')}` : ''}`);
};
const logIssueSet = (issues, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        issues
            .sort((a, b) => (a.owner < b.owner ? -1 : 1))
            .forEach(issue => console.log(issue.owner, issue.symbol.startsWith('/') ? (0, path_1.relative)(issue.symbol) : issue.symbol));
    }
    else {
        console.log('Not found');
    }
};
const logIssueRecord = (issues, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        const sortedByFilePath = issues.sort((a, b) => (a.owner < b.owner ? -1 : 1));
        sortedByFilePath.forEach(({ filePath, symbols, owner }) => logIssueLine(owner, filePath, symbols));
    }
    else {
        console.log('Not found');
    }
};
exports.default = ({ report, issues, options }) => {
    let opts = {};
    try {
        opts = options ? JSON.parse(options) : opts;
    }
    catch (error) {
        console.error(error);
    }
    const codeownersFilePath = node_path_1.default.resolve(opts.path ?? '.github/CODEOWNERS');
    const codeownersEngine = ownership_1.OwnershipEngine.FromCodeownersFile(codeownersFilePath);
    const reportMultipleGroups = Object.values(report).filter(Boolean).length > 1;
    const [dependenciesOwner = '[no-owner]'] = codeownersEngine.calcFileOwnership('package.json');
    const fallbackOwner = dependenciesOwner;
    const calcFileOwnership = (filePath) => codeownersEngine.calcFileOwnership((0, path_1.relative)(filePath))[0] ?? fallbackOwner;
    const addOwner = (issue) => ({ ...issue, owner: calcFileOwnership(issue.filePath) });
    for (const [reportType, isReportType] of Object.entries(report)) {
        if (isReportType) {
            const title = reportMultipleGroups && constants_1.ISSUE_TYPE_TITLE[reportType];
            if (issues[reportType] instanceof Set) {
                const toIssue = (filePath) => ({ filePath, symbol: filePath });
                const issuesForType = Array.from(issues[reportType]).map(toIssue);
                logIssueSet(issuesForType.map(addOwner), title);
            }
            else if (reportType === 'duplicates') {
                const issuesForType = Object.values(issues[reportType]).map(Object.values).flat().map(addOwner);
                logIssueRecord(issuesForType, title);
            }
            else {
                const issuesForType = Object.values(issues[reportType]).map(issues => {
                    const items = Object.values(issues);
                    return addOwner({ ...items[0], symbols: items.map(issue => issue.symbol) });
                });
                logIssueRecord(issuesForType, title);
            }
        }
    }
};
