"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("../util/path");
const constants_1 = require("./constants");
const logIssueLine = (filePath, symbols) => {
    console.log(`${(0, path_1.relative)(filePath)}${symbols ? `: ${symbols.join(', ')}` : ''}`);
};
const logIssueSet = (issues, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        issues.sort().forEach(value => console.log(value.startsWith('/') ? (0, path_1.relative)(value) : value));
    }
    else {
        console.log('Not found');
    }
};
const logIssueRecord = (issues, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        const sortedByFilePath = issues.sort((a, b) => (a.filePath > b.filePath ? 1 : -1));
        sortedByFilePath.forEach(({ filePath, symbols }) => logIssueLine(filePath, symbols));
    }
    else {
        console.log('Not found');
    }
};
exports.default = ({ report, issues }) => {
    const reportMultipleGroups = Object.values(report).filter(Boolean).length > 1;
    for (const [reportType, isReportType] of Object.entries(report)) {
        if (isReportType) {
            const title = reportMultipleGroups && constants_1.ISSUE_TYPE_TITLE[reportType];
            if (issues[reportType] instanceof Set) {
                logIssueSet(Array.from(issues[reportType]), title);
            }
            else if (reportType === 'duplicates') {
                const issuesForType = Object.values(issues[reportType]).map(Object.values).flat();
                logIssueRecord(issuesForType, title);
            }
            else {
                const issuesForType = Object.values(issues[reportType]).map(issues => {
                    const items = Object.values(issues);
                    return { ...items[0], symbols: items.map(issue => issue.symbol) };
                });
                logIssueRecord(issuesForType, title);
            }
        }
    }
};
