"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const fs_1 = require("../util/fs");
const path_1 = require("../util/path");
const ownership_1 = require("@snyk/github-codeowners/dist/lib/ownership");
const mergeTypes = (type) => type === 'exports' || type === 'nsExports' ? 'exports' : type === 'types' || type === 'nsTypes' ? 'types' : type;
exports.default = async ({ report, issues, options }) => {
    let opts = {};
    try {
        opts = options ? JSON.parse(options) : opts;
    }
    catch (error) {
        console.error(error);
    }
    const json = {};
    const codeownersFilePath = node_path_1.default.resolve(opts.codeowners ?? '.github/CODEOWNERS');
    const codeownersEngine = (await (0, fs_1.isFile)(codeownersFilePath)) && ownership_1.OwnershipEngine.FromCodeownersFile(codeownersFilePath);
    const flatten = (issues) => Object.values(issues).map(Object.values).flat();
    const initRow = (filePath) => {
        const file = (0, path_1.relative)(filePath);
        const row = {
            file,
            ...(codeownersEngine && { owners: codeownersEngine.calcFileOwnership(file) }),
            ...(report.files && { files: false }),
            ...(report.unlisted && { unlisted: [] }),
            ...((report.exports || report.nsExports) && { exports: [] }),
            ...((report.types || report.nsTypes) && { types: [] }),
            ...(report.duplicates && { duplicates: [] }),
        };
        return row;
    };
    for (const [reportType, isReportType] of Object.entries(report)) {
        if (isReportType) {
            if (reportType === 'files') {
                Array.from(issues[reportType]).forEach(filePath => {
                    json[filePath] = json[filePath] ?? initRow(filePath);
                    json[filePath][reportType] = true;
                });
            }
            else {
                const type = mergeTypes(reportType);
                flatten(issues[reportType]).forEach(({ filePath, symbol }) => {
                    json[filePath] = json[filePath] ?? initRow(filePath);
                    json[filePath][type]?.push(symbol);
                });
            }
        }
    }
    console.log(JSON.stringify(Object.values(json)));
};
