import { SourceFile } from 'ts-morph';
declare type SymbolType = 'type' | 'interface' | 'enum';
export declare type Issue = {
    filePath: string;
    symbol: string;
    symbols?: string[];
    symbolType?: SymbolType;
};
export declare type IssueSet = Set<string>;
export declare type IssueRecords = Record<string, Record<string, Issue>>;
export declare type Issues = {
    files: IssueSet;
    dependencies: IssueSet;
    devDependencies: IssueSet;
    unlisted: IssueRecords;
    exports: IssueRecords;
    types: IssueRecords;
    nsExports: IssueRecords;
    nsTypes: IssueRecords;
    duplicates: IssueRecords;
};
export declare type IssueType = keyof Issues;
export declare type ProjectIssueType = Extract<IssueType, 'files' | 'dependencies' | 'devDependencies'>;
export declare type SymbolIssueType = Exclude<IssueType, ProjectIssueType>;
export declare type Report = {
    [key in keyof Issues]: boolean;
};
declare type BaseLocalConfiguration = {
    entryFiles: string[];
    projectFiles: string[];
};
export declare type LocalConfiguration = BaseLocalConfiguration & {
    dev?: boolean | BaseLocalConfiguration;
    include?: string[];
    exclude?: string[];
};
export declare type ImportedConfiguration = LocalConfiguration | Record<string, LocalConfiguration>;
export declare type UnresolvedConfiguration = {
    cwd: string;
    workingDir: string;
    configFilePath?: string;
    tsConfigFilePath?: string;
    include: string[];
    exclude: string[];
    ignore: string[];
    gitignore: boolean;
    isIncludeEntryFiles: boolean;
    isDev: boolean;
    isShowProgress: boolean;
    jsDoc: string[];
    debug: {
        isEnabled: boolean;
        level: number;
    };
};
export declare type Configuration = {
    workingDir: string;
    report: Report;
    projectFiles: SourceFile[];
    productionFiles: SourceFile[];
    entryFiles: SourceFile[];
    isIncludeEntryFiles: boolean;
    dependencies: string[];
    peerDependencies: string[];
    optionalDependencies: string[];
    devDependencies: string[];
    isDev: boolean;
    tsConfigPaths: string[];
    isShowProgress: boolean;
    jsDocOptions: {
        isReadPublicTag: boolean;
    };
    debug: {
        isEnabled: boolean;
        level: number;
    };
};
export declare type Counters = Record<IssueType | 'processed' | 'total', number>;
export declare type ReporterOptions = {
    report: Report;
    issues: Issues;
    cwd: string;
    workingDir: string;
    isDev: boolean;
    options: string;
};
export declare type Reporter = (options: ReporterOptions) => void;
export {};
