"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.debugLogSourceFiles = exports.debugLogFiles = exports.debugLogObject = void 0;
const node_util_1 = __importDefault(require("node:util"));
const logArray = (collection) => console.log(node_util_1.default.inspect(collection, { maxArrayLength: null }));
const debugLogObject = (config, minimumLevel, name, obj) => {
    if (minimumLevel > config.debug.level)
        return;
    console.log(`[knip] ${name}:`);
    console.log(node_util_1.default.inspect(obj, { depth: null, colors: true }));
};
exports.debugLogObject = debugLogObject;
const debugLogFiles = (config, minimumLevel, name, filePaths) => {
    if (minimumLevel > config.debug.level)
        return;
    const { debug } = config;
    if (debug.level > 1) {
        console.debug(`[knip] ${name} (${filePaths.length}):`);
        logArray(filePaths);
    }
    else {
        console.debug(`[knip] ${name} (${filePaths.length})`);
    }
};
exports.debugLogFiles = debugLogFiles;
const debugLogSourceFiles = (config, minimumLevel, name, sourceFiles) => {
    if (minimumLevel > config.debug.level)
        return;
    const { debug } = config;
    if (debug.level > 1) {
        console.debug(`[knip] ${name} (${sourceFiles.length}):`);
        logArray(sourceFiles.map(sourceFile => sourceFile.getFilePath()));
    }
    else {
        console.debug(`[knip] ${name} (${sourceFiles.length})`);
    }
};
exports.debugLogSourceFiles = debugLogSourceFiles;
const debugLogDiff = (config, minimumLevel, name, arrA, arrB) => {
    if (minimumLevel > config.debug.level)
        return;
    const onlyInA = arrA.filter(itemA => !arrB.includes(itemA)).sort();
    const onlyInB = arrB.filter(itemB => !arrA.includes(itemB)).sort();
    console.log(`[knip] ${name}`);
    console.log(`[knip] Only in left:`);
    logArray(onlyInA);
    console.log();
    console.log(`[knip] Only in right:`);
    logArray(onlyInB);
};
